@@ -1,5 +1,7 @@
 test_format <- function(name, output_options = NULL, skip = NULL) {
 
+  withr::local_options(lifecycle_verbosity = "quiet")
+
   # don't run on CRAN due to complicated dependencies (Pandoc/LaTeX packages)
   if (!identical(Sys.getenv("NOT_CRAN"), "true")) return()
   # skip if requested
@@ -36,7 +38,7 @@ test_format("acm")
 test_format("acs")
 test_format("aea")
 test_format("agu")
-test_format("ajs")
+test_format("ajs", skip = !rmarkdown::pandoc_available("2.7"))
 test_format("amq")
 test_format("ams")
 test_format("arxiv")
@@ -55,9 +57,12 @@ test_format("informs", skip = !rmarkdown::pandoc_available("2.10"))
 test_format("isba", skip = !rmarkdown::pandoc_available("2.10"))
 test_format("iop")
 test_format("jasa")
+test_format("jedm")
 test_format("joss")
 test_format("joss", output_options = list(journal = "JOSE"))
-test_format("jss")
+test_format("jss", skip = !rmarkdown::pandoc_available("2.7"))
+test_format("lncs")
+test_format("lncs", output_options = list(citation_package = "natbib"))
 test_format("lipics")
 test_format("mdpi")
 test_format("mnras")
@@ -72,7 +77,8 @@ test_format("rsos")
 test_format("rss")
 test_format("sage")
 test_format("sim")
-test_format("springer")
+test_format("springer", skip = !rmarkdown::pandoc_available("2.11.4"))
 test_format("tf")
 test_format("trb")
-test_format("wellcomeor")
+# Deactivate because of https://github.com/rstudio/rticles/issues/523
+# test_format("wellcomeor")
