@@ -38,13 +38,24 @@ assert("all journals are listed and have a template folder", {
 })
 
 assert("Named vector is transformed to pandoc variable args", {
-  (vec_to_pandoc_variable_args(c(a = "b")) %==%
+  (list_to_pandoc_variable_args(c(a = "b")) %==%
     c(rmarkdown::pandoc_variable_arg("a", "b"))
   )
-  (vec_to_pandoc_variable_args(c(a = "b", c = "d")) %==%
+  (list_to_pandoc_variable_args(c(a = "b", c = "d")) %==%
     c(
       rmarkdown::pandoc_variable_arg("a", "b"),
       rmarkdown::pandoc_variable_arg("c", "d")
     )
   )
+  (list_to_pandoc_variable_args(list(c = TRUE)) %==%
+    c(
+      rmarkdown::pandoc_variable_arg("c")
+    )
+  )
+  (list_to_pandoc_variable_args(list(a = "b", c = TRUE)) %==%
+    c(
+      rmarkdown::pandoc_variable_arg("a", "b"),
+      rmarkdown::pandoc_variable_arg("c")
+    )
+  )
 })
